write_end_redacted

Function write_end_redacted 

pub fn write_end_redacted(
    f: &mut Formatter<'_>,
    input: &str,
    chars: usize,
    ellipsis: &str,
) -> Result
Write up to chars characters from the end of input onto f.

If any characters are removed, replace them with ellipsis.