write_start_redacted

Function write_start_redacted 

pub fn write_start_redacted(
    f: &mut Formatter<'_>,
    input: &str,
    chars: usize,
    ellipsis: &str,
) -> Result
Write up to chars characters from the start of input onto f.

If any characters are removed, replace them with ellipsis.